| clean_name | R Documentation |
Clean variable name(s) to create syntactically valid, unique names for use in R and Julia.
clean_name(new, existing, protected = c())
new |
Vector of names to transform to valid names |
existing |
Vector of existing names in model |
protected |
Optional vector of protected names |
Vector of cleaned names
sfm <- xmile("predator_prey")
# As the variable name "predator" is already taken, clean_name() will create
# an unique name
clean_name("predator", as.data.frame(sfm)[["name"]]) # "predator_1"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.