| drop_u | R Documentation |
In rare cases, it may be desirable to drop the units of a variable within an equation. Use drop_u() to render a variable unitless. See u() for more information on the rules of specifying units. Note that units are only supported in Julia, not in R.
drop_u(x)
x |
Variable with unit |
Unitless variable (only in Julia)
model_units(), unit_prefixes(), u(), convert_u()
# For example, the cosine function only accepts unitless arguments or
# arguments with units in radians or degrees
sfm <- xmile() |>
build("a", "constant", eqn = "10", units = "minutes") |>
build("b", "constant", eqn = "cos(drop_u(a))")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.