find_dependencies: Find dependencies

View source: R/simulate.R

find_dependenciesR Documentation

Find dependencies

Description

Find which other variables each variable is dependent on.

Usage

find_dependencies(sfm, reverse = FALSE)

Arguments

sfm

Stock-and-flow model, object of class sdbuildR_xmile.

reverse

If FALSE, list for each variable X which variables Y it depends on for its equation definition. If TRUE, don't show dependencies but dependents. This reverses the dependencies, such that for each variable X, it lists what other variables Y depend on X.

Value

List, with for each model variable what other variables it depends on, or if reverse = TRUE, which variables depend on it

Examples

sfm <- xmile("SIR")
find_dependencies(sfm)


sdbuildR documentation built on Nov. 19, 2025, 5:07 p.m.