| get_units | R Documentation |
Obtain a data frame with all standard units in Julia's Unitful package and added custom units by sdbuildR.
get_units()
A character matrix with 5 columns: description (unit description),
name (unit symbol or abbreviation), full_name (full unit name),
definition (mathematical definition in terms of base units), and prefix
(logical indicating whether SI prefixes like kilo- or milli- can be applied).
Includes SI base units, derived units, CGS units, US customary units, and
custom units added by sdbuildR.
x <- get_units()
head(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.