Computes the Hill function with configurable slope, midpoint, and upper asymptote.
Details
The Hill function is a smooth S-shaped curve (when slope > 1) bounded between 0 and upper.
It transitions from near 0 to near upper around the midpoint, with the steepness
of this transition controlled by slope. See https://en.wikipedia.org/wiki/Hill_equation_%28biochemistry%29 for more details.