| julia_status | R Documentation |
Check if Julia can be found and if the Julia environment for sdbuildR has been instantiated. Note that this does not mean a Julia session has been started, merely whether it could be. For more guidance, please see this vignette.
julia_status(verbose = TRUE)
verbose |
If TRUE, print detailed status information. Defaults to TRUE. |
A list with components:
julia_found |
Logical. TRUE if Julia installation found. |
julia_version |
Character. Julia version string, or "" if not found. |
env_exists |
Logical. TRUE if Project.toml exists in sdbuildR package, which specifies the Julia packages and versions needed to instantiate the Julia environment for sdbuildR. |
env_instantiated |
Logical. TRUE if Manifest.toml exists (i.e., Julia environment was instantiated). |
status |
Character. Overall status: "julia_not_installed", "julia_needs_update", "sdbuildR_needs_reinstall", "install_julia_env", "ready", or "unknown". |
Based on the 'status' value:
Install Julia from https://julialang.org/install/
Update Julia to >= version 1.10
Run install_julia_env()
Run use_julia() to start a session
status <- julia_status()
print(status)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.