length_IM: Length of vector or string

View source: R/custom_func.R

length_IMR Documentation

Length of vector or string

Description

Equivalent of .Length() in Insight Maker, which returns the number of elements when performed on a vector, but returns the number of characters when performed on a string

Usage

length_IM(x)

Arguments

x

A vector or a string

Value

The number of elements in x if x is a vector; the number of characters in x if x is a string

Examples

length_IM(c("a", "b", "c")) # 3
length_IM("abcdef") # 6

sdbuildR documentation built on Nov. 19, 2025, 5:07 p.m.