rem_mod: Remainder and modulus

remR Documentation

Remainder and modulus

Description

Remainder and modulus operators. The modulus and remainder are not the same in case either a or b is negative. If you work with negative numbers, modulus is always non-negative (it matches the sign of the divisor).

Usage

rem(a, b)

mod(a, b)

a %REM% b

Arguments

a

Dividend

b

Divisor

Value

Remainder

Examples

# Modulus and remainder are the same when a and b are positive
a <- 7
b <- 3
rem(a, b)
mod(a, b)
# Modulus and remainder are NOT when either a or b is negative
a <- -7
b <- 3
rem(a, b)
mod(a, b)
a <- 7
b <- -3
rem(a, b)
mod(a, b)
# Modulus and remainder are the same when both a and b are negative
a <- -7
b <- -3
rem(a, b)
mod(a, b)

# Alternative way of computing the remainder:
a %REM% b

sdbuildR documentation built on Nov. 19, 2025, 5:07 p.m.