Skip to contents

sdbuildR provides a print() method for each of its object classes, called automatically when an object is shown at the console:

Details

print.stockflow()

Overview of a stock-and-flow model.

print.simulate_stockflow()

Overview of a simulation.

print.summary_stockflow()

Model diagnostics from summary().

print.compare_stockflow()

Comparison of two models from compare_models().

print() methods are also defined for ensemble_stockflow, verify_stockflow and unit_tests_stockflow objects.