| summary.sdbuildR_xmile | R Documentation |
Print summary of stock-and-flow model, including number of stocks, flows, constants, auxiliaries, graphical functions, macros, and custom model units, as well as simulation specifications and use of delay functions.
## S3 method for class 'sdbuildR_xmile'
summary(object, ...)
object |
A stock-and-flow model object of class |
... |
Optional arguments |
Summary object of class summary.sdbuildR_xmile
build()
sfm <- xmile("SIR")
summary(sfm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.