- object
Stock-and-flow model, object of class stockflow.
- name
Variable names to find dependencies for. Defaults to NULL to include all variables.
- type
Variable types to find dependencies for. Must be one or more of 'stock', 'flow', 'constant', 'aux', 'gf', or 'func'. Defaults to NULL to include all types.
- reverse
If FALSE, list for each variable X which variables Y it depends on for its equation definition. If TRUE, don't show dependencies but dependents. This reverses the dependencies, such that for each variable X, it lists what other variables Y depend on X.