| find_dependencies | R Documentation |
Find which other variables each variable is dependent on.
find_dependencies(sfm, reverse = FALSE)
sfm |
Stock-and-flow model, object of class |
reverse |
If FALSE, list for each variable X which variables Y it depends on for its equation definition. If TRUE, don't show dependencies but dependents. This reverses the dependencies, such that for each variable X, it lists what other variables Y depend on X. |
List, with for each model variable what other variables it depends on, or if reverse = TRUE, which variables depend on it
sfm <- xmile("SIR")
find_dependencies(sfm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.