Print the first rows of a simulation data frame of a stock-and-flow model. This is a wrapper around head() that first converts the simulation results to a data frame using as.data.frame().
Usage
# S3 method for class 'simulate_stockflow'
head(x, n = 6L, ...)Arguments
- x
Output of
simulate().- n
Number of rows to print. Defaults to 6.
- ...
Other arguments passed to
as.data.frame.simulate_stockflow().