head.simulate_stockflow: Print first rows of a simulation
Description
Print the first rows of a simulation data frame of a stock-and-flow model. This is a wrapper around head() that first converts the simulation results to a data frame using as.data.frame().
Usage
# S3 method for simulate_stockflow
head(x, n = 6L, ...)
Value
A data.frame with the first rows of the simulation results.