Instantiate the Julia environment for sdbuildR to run stock-and-flow models using Julia. For more guidance, see this vignette.
Arguments
- remove
If
TRUE, remove Julia environment for sdbuildR. This will remove the SystemDynamicsBuildR.jl package and delete the environment directory (containing Project.toml and Manifest.toml). All other Julia packages remain untouched.- quiet
If
TRUE, suppress informational messages such as progress and status updates. Warnings and errors are always shown. Defaults toFALSE.
Details
install_julia_env() will:
Start a Julia session
Activate a Julia environment using sdbuildR's Project.toml
Install SystemDynamicsBuildR.jl from GitHub (https://github.com/kcevers/SystemDynamicsBuildR.jl)
Install all other required Julia packages
Create Manifest.toml
Precompile packages for faster subsequent loading
Stop the Julia session
Note that this may take 10-25 minutes the first time as Julia downloads and compiles packages.