| length_IM | R Documentation |
Equivalent of .Length() in Insight Maker, which returns the number of elements when performed on a vector, but returns the number of characters when performed on a string
length_IM(x)
x |
A vector or a string |
The number of elements in x if x is a vector; the number of characters in x if x is a string
length_IM(c("a", "b", "c")) # 3
length_IM("abcdef") # 6
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.