Equivalent of .Length() in Insight Maker, which returns the number of elements when performed on a vector, but returns the number of characters when performed on a string
Usage
length_IM(x)
Value
The number of elements in x if x is a vector; the number of characters in x if x is a string