Learn R Programming

sdbuildR (version 2.0.0)

meta: Modify meta of stock-and-flow model

Description

The meta of a stock-and-flow model contains metadata about the model, such as the name, author, and version. Modify the meta of an existing model with standard or custom properties.

Usage

meta(
  object,
  name = "My Model",
  caption = "My Model Description",
  created = Sys.time(),
  author = "Me",
  version = "1.0",
  URL = "",
  doi = "",
  ...
)

Value

A stock-and-flow model object of class stockflow

Arguments

object

Stock-and-flow model, object of class stockflow.

name

Model name. Defaults to "My Model".

caption

Model description. Defaults to "My Model Description".

created

Date the model was created. Defaults to Sys.time().

author

Creator of the model. Defaults to "Me".

version

Model version. Defaults to "1.0".

URL

URL associated with model. Defaults to "".

doi

DOI associated with the model. Defaults to "".

...

Optional other entries to add to the meta.

Examples

Run this code
sfm <- stockflow() |>
  meta(
    name = "My first model",
    caption = "This is my first model",
    author = "Kyra Evers",
    version = "1.1"
  )

Run the code above in your browser using DataLab