The meta of a stock-and-flow model contains metadata about the model, such as the name, author, and version. Modify the meta of an existing model with standard or custom properties.
Usage
meta(
object,
name = "My Model",
caption = "My Model Description",
created = Sys.time(),
author = "Me",
version = "1.0",
URL = "",
doi = "",
...
)
Value
A stock-and-flow model object of class stockflow
Arguments
object
Stock-and-flow model, object of class stockflow.
name
Model name. Defaults to "My Model".
caption
Model description. Defaults to "My Model Description".
created
Date the model was created. Defaults to Sys.time().