| ramp | R Documentation |
Create a ramp function that increases linearly from 0 to a specified height at a specified start time, and stays at this height after the specified end time.
ramp(times, start, finish, height = 1)
times |
Vector of simulation times |
start |
Start time of ramp |
finish |
End time of ramp |
height |
End height of ramp, defaults to 1 |
Equivalent of Ramp() in Insight Maker
Ramp interpolation function
step(), pulse(), seasonal()
# Create a simple model with a ramp function
sfm <- xmile() |>
build("a", "stock") |>
# Specify the global variable "times" as simulation times
build("input", "constant", eqn = "ramp(times, 20, 30, 3)") |>
build("inflow", "flow", eqn = "input(t)", to = "a")
sim <- simulate(sfm, only_stocks = FALSE)
plot(sim)
# To create a decreasing ramp, set the height to a negative value
sfm <- build(sfm, "input", eqn = "ramp(times, 20, 30, -3)")
sim <- simulate(sfm, only_stocks = FALSE)
plot(sim)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.