Name of the template to load. If NULL, an empty stock-and-flow
model will be created with default simulation parameters and a default meta.
If specified, template should be one of the available templates (case-insensitive):
logistic_model: Population growth with carrying capacity
sir: Epidemic model (Susceptible-Infected-Recovered)
predator_prey: Lotka-Volterra dynamics
cusp: Cusp catastrophe model
crielaard2022: Eating behavior (doi: 10.1037/met0000484)
coffee_cup: Temperature equilibration (Meadows)
bank_account: Compound interest (Meadows)
lorenz: Lorenz attractor (chaotic)
rossler: Rossler attractor (chaotic)
vanderpol: Van der Pol oscillator
duffing: Forced Duffing oscillator
chua: Chua's circuit (chaotic)
jdr: Job Demands-Resources Theory as formalized in Evers et al. (under review)