tail.simulate_stockflow: Print last rows of a simulation
Description
Print the last rows of a simulation data frame of a stock-and-flow model. This is a wrapper around tail() that first converts the simulation results to a data frame using as.data.frame().
Usage
# S3 method for simulate_stockflow
tail(x, n = 6L, ...)
Value
A data.frame with the last rows of the simulation results.