| use_julia | R Documentation |
Start Julia session and activate Julia environment to simulate stock-and-flow models. To do so, Julia needs to be installed and findable from within R. See this vignette for guidance. In addition, the Julia environment specifically for sdbuildR needs to have been instantiated. This can be set up with install_julia_env().
use_julia(stop = FALSE, force = FALSE)
stop |
If TRUE, stop active Julia session. Defaults to FALSE. |
force |
If TRUE, force Julia setup to execute again. |
Julia supports running stock-and-flow models with units as well as ensemble simulations (see ensemble()).
In every R session, use_julia() needs to be run once (which is done automatically in simulate()), which can take around 30-60 seconds.
Returns NULL invisibly, used for side effects
julia_status(), install_julia_env()
# Start a Julia session and activate the Julia environment for sdbuildR
use_julia()
# Stop Julia session
use_julia(stop = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.